* --------------------------------------------------------------------
* Project: The Effect of Information and Communication Technologies
*          on Urban Structure 
*          published in: Economic Policy, April 2008, pp. 201 - 242
* Authors: Yannis M. Ioannides, Henry G. Overman, 
*          Esteban Rossi-Hansberg, and Kurt Schmidheiny 
* Date:    December 7, 2007
* File:    table2.do
* Title:   Phone lines and the city size distribution
* --------------------------------------------------------------------

set more off
clear
use twostep.dta, clear

* --------------------------------------------------------------------
* restrict sample
* --------------------------------------------------------------------

* drop Germany
drop if countrycode == "DEU"

* restrict to Europe and Northern America
drop if ~(europe==1|northamerica==1)

* restrict to observations up to 2000
drop if year > 2000
drop if year < 1980

* --------------------------------------------------------------------
* data structure
* --------------------------------------------------------------------

* panel structure
tsset countryid time 

* --------------------------------------------------------------------
* create sample specific time averages
* --------------------------------------------------------------------

by countryid: egen govexp_avgpan = mean(govexp_mix)
lab var govexp_avgpan "=  mean(govexp_mix), years with city observations"

by countryid: egen obs_avgpan = mean(obs_cities_sc)
lab var obs_avgpan "=  mean(obs), years with city observations"

* --------------------------------------------------------------------
* estimation
* --------------------------------------------------------------------

estimates clear

* common sample for all estimations
quietly reg alpha05_lin_cities lphones_sc invroaddens lnpop lngdppcppp trade nonagriva  govexp_avgpan gdpgrowth_sd lnarea obs_avgpan time
generate sample = e(sample)

* weights
generate weight = 1/(sealpha_lin_cities^2)

* reference for within R2: only fixed effects
xi: reg alpha05_lin_cities i.countryid if sample [aw=weight]
estimates store m0
scalar rss_fixed = e(rss)

* column [1]: univariate, no fixed effects
reg alpha05_lin_cities lphones_sc time if sample [aw=weight]
estimates store m1

* column [2]: multivariate, no fixed effects
reg alpha05_lin_cities lphones_sc invroaddens lnpop lngdppcppp trade nonagriva  govexp_avgpan gdpgrowth_sd lnarea obs_avgpan time if sample [aw=weight]
estimates store m2

* column [3]: univariate, fixed effects
xi: reg alpha05_lin_cities lphones_sc i.countryid time if sample [aw=weight]
estimates store m3
scalar r2_3 = (1-e(rss)/rss_fixed)

* column [4]: multivariate, fixed effects
xi: reg alpha05_lin_cities lphones_sc invroaddens lnpop lngdppcppp trade nonagriva time i.countryid if sample [aw=weight]
estimates store m4
scalar r2_4 = (1-e(rss)/rss_fixed)

* column [5]: univariate, no fixed effects, iv
ivreg alpha05_lin_cities (lphones_sc = monopub monopriv timeaftermonopub timeaftermonopriv eu nafta) time if sample [aw=weight]
estimates store m5

* column [6]: multivariate, no fixed effects, iv
ivreg alpha05_lin_cities (lphones_sc = monopub monopriv timeaftermonopub timeaftermonopriv eu nafta) invroaddens lnpop lngdppcppp trade nonagriva govexp_avgpan gdpgrowth_sd lnarea obs_avgpan time if sample [aw=weight]
estimates store m6

* column [7]: univariate, fixed effects, iv
xi: ivreg alpha05_lin_cities (lphones_sc = monopub monopriv timeaftermonopub timeaftermonopriv eu nafta) i.countryid time if sample [aw=weight]
estimates store m7
scalar r2_7 = (1-e(rss)/rss_fixed)

* column [8]: multivariate, fixed effects, iv
xi: ivreg alpha05_lin_cities (lphones_sc = monopub monopriv timeaftermonopub timeaftermonopriv eu nafta) invroaddens lnpop lngdppcppp trade nonagriva time i.countryid if sample [aw=weight]
estimates store m8
scalar r2_8 = (1-e(rss)/rss_fixed)

* column [9], not reported: multivariate, fixed effects, iv, controlling for RegRef
xi: ivreg alpha05_lin_cities (lphones_sc = monopub monopriv timeaftermonopub timeaftermonopriv eu nafta) invroaddens lnpop lngdppcppp trade nonagriva regref time i.countryid if sample [aw=weight]
estimates store m9
generate newsample = e(sample)

* column [10], not reported: multivariate, fixed effects, iv, not controlling for RegRef but reduced sample
xi: ivreg alpha05_lin_cities (lphones_sc = monopub monopriv timeaftermonopub timeaftermonopriv eu nafta) invroaddens lnpop lngdppcppp trade nonagriva time i.countryid if newsample [aw=weight]
estimates store m10

* produce output table, tab-delimited text
set linesize 255
estout * using table2.txt, stats(r2 N N_g rss) cells(b(star fmt(%9.3f)) se(fmt(%9.3f))) margin legend replace
estimates clear

* --------------------------------------------------------------------
* explicitely demand first stage results
* --------------------------------------------------------------------

* reference for within R2: only fixed effects
xi: reg lphones_sc i.countryid if sample [aw=weight]
estimates store m01
scalar rss_fixed = e(rss)

reg lphones_sc monopub monopriv timeaftermonopub timeaftermonopriv eu nafta time if sample [aw=weight]
estimates store m51
test monopub monopriv timeaftermonopub timeaftermonopriv eu nafta
scalar F_51 = r(F)

reg lphones_sc monopub monopriv timeaftermonopub timeaftermonopriv eu nafta invroaddens lnpop lngdppcppp trade nonagriva  govexp_avgpan gdpgrowth_sd lnarea obs_avgpan time if sample [aw=weight]
test monopub monopriv timeaftermonopub timeaftermonopriv eu nafta
scalar F_61 = r(F)
estimates store m61

xi: reg lphones_sc monopub monopriv timeaftermonopub timeaftermonopriv eu nafta time i.countryid if sample [aw=weight]
estimates store m71
scalar r2_71 = (1-e(rss)/rss_fixed)
test monopub monopriv timeaftermonopub timeaftermonopriv eu nafta
scalar F_71 = r(F)

xi: reg lphones_sc monopub monopriv timeaftermonopub timeaftermonopriv eu nafta invroaddens lnpop lngdppcppp trade nonagriva time i.countryid if sample [aw=weight]
estimates store m81
test monopub monopriv timeaftermonopub timeaftermonopriv eu nafta
scalar r2_81 = (1-e(rss)/rss_fixed)
scalar F_81 = r(F)

* produce output table, tab-delimited text
set linesize 255
estout * using table3.txt, stats(r2 N N_g rss) cells(b(star fmt(%9.3f)) se(fmt(%9.3f))) margin legend replace
estimates clear

disp r2_3
disp r2_4
disp r2_7
disp r2_8

disp r2_71
disp r2_81

disp F_51
disp F_61
disp F_71
disp F_81

* --------------------------------------------------------------------
* descriptive statistics
* --------------------------------------------------------------------

sum phones_sc lphones_sc invroaddens pop lnpop gdppcppp lngdppcppp trade nonagriva govexp_avgpan gdpgrowth_sd landarea lnarea obs_avgpan if sample
